@@ -38,7 +38,6 @@ from .config import TESSDATA_PREFIX, OCRD_TOOL
 from .segment_region import polygon_for_parent
 
 TOOL = 'ocrd-tesserocr-recognize'
-LOG = getLogger('processor.TesserocrRecognize')
 
 CHOICE_THRESHOLD_NUM = 6 # maximum number of choices to query and annotate
 CHOICE_THRESHOLD_CONF = 0.2 # maximum score drop from best choice to query and annotate
@@ -80,6 +79,7 @@ class TesserocrRecognize(Processor):
         
         Produce new output files by serialising the resulting hierarchy.
         """
+        LOG = getLogger('processor.TesserocrRecognize')
         LOG.debug("TESSDATA: %s, installed Tesseract models: %s", *get_languages())
 
         assert_file_grp_cardinality(self.input_file_grp, 1)
@@ -197,18 +197,13 @@ class TesserocrRecognize(Processor):
                     content=to_xml(pcgts))
 
     def _process_regions(self, tessapi, regions, page_image, page_xywh):
+        LOG = getLogger('processor.TesserocrRecognize')
         for region in regions:
             region_image, region_xywh = self.workspace.image_from_segment(
                 region, page_image, page_xywh)
             if self.parameter['textequiv_level'] == 'region':
                 if self.parameter['padding']:
-                    bg = tuple(ImageStat.Stat(region_image).median)
-                    pad = self.parameter['padding']
-                    padded = Image.new(region_image.mode,
-                                       (region_image.width + 2 * pad,
-                                        region_image.height + 2 * pad), bg)
-                    padded.paste(region_image, (pad, pad))
-                    tessapi.SetImage(padded)
+                    tessapi.SetImage(pad_image(region_image, self.parameter['padding']))
                 else:
                     tessapi.SetImage(region_image)
                 tessapi.SetPageSegMode(PSM.SINGLE_BLOCK)
@@ -230,6 +225,7 @@ class TesserocrRecognize(Processor):
                 self._process_lines(tessapi, textlines, region_image, region_xywh)
 
     def _process_lines(self, tessapi, textlines, region_image, region_xywh):
+        LOG = getLogger('processor.TesserocrRecognize')
         for line in textlines:
             if self.parameter['overwrite_words']:
                 line.set_Word([])
@@ -237,13 +233,7 @@ class TesserocrRecognize(Processor):
                 line, region_image, region_xywh)
             # todo: Tesseract works better if the line images have a 5px margin everywhere
             if self.parameter['padding']:
-                bg = tuple(ImageStat.Stat(line_image).median)
-                pad = self.parameter['padding']
-                padded = Image.new(line_image.mode,
-                                   (line_image.width + 2 * pad,
-                                    line_image.height + 2 * pad), bg)
-                padded.paste(line_image, (pad, pad))
-                tessapi.SetImage(padded)
+                tessapi.SetImage(pad_image(line_image, self.parameter['padding']))
             else:
                 tessapi.SetImage(line_image)
             if self.parameter['raw_lines']:
@@ -273,6 +263,7 @@ class TesserocrRecognize(Processor):
                 self._process_words_in_line(tessapi.GetIterator(), line, line_xywh)
 
     def _process_words_in_line(self, result_it, line, line_xywh):
+        LOG = getLogger('processor.TesserocrRecognize')
         if not result_it or result_it.Empty(RIL.WORD):
             LOG.warning("No text in line '%s'", line.id)
             return
@@ -327,17 +318,12 @@ class TesserocrRecognize(Processor):
                 result_it.Next(RIL.WORD)
 
     def _process_existing_words(self, tessapi, words, line_image, line_xywh):
+        LOG = getLogger('processor.TesserocrRecognize')
         for word in words:
             word_image, word_xywh = self.workspace.image_from_segment(
                 word, line_image, line_xywh)
             if self.parameter['padding']:
-                bg = tuple(ImageStat.Stat(word_image).median)
-                pad = self.parameter['padding']
-                padded = Image.new(word_image.mode,
-                                   (word_image.width + 2 * pad,
-                                    word_image.height + 2 * pad), bg)
-                padded.paste(word_image, (pad, pad))
-                tessapi.SetImage(padded)
+                tessapi.SetImage(pad_image(word_image, self.parameter['padding']))
             else:
                 tessapi.SetImage(word_image)
             tessapi.SetPageSegMode(PSM.SINGLE_WORD)
@@ -364,17 +350,12 @@ class TesserocrRecognize(Processor):
                 self._process_glyphs_in_word(tessapi.GetIterator(), word, word_xywh)
 
     def _process_existing_glyphs(self, tessapi, glyphs, word_image, word_xywh):
+        LOG = getLogger('processor.TesserocrRecognize')
         for glyph in glyphs:
             glyph_image, _ = self.workspace.image_from_segment(
                 glyph, word_image, word_xywh)
             if self.parameter['padding']:
-                bg = tuple(ImageStat.Stat(glyph_image).median)
-                pad = self.parameter['padding']
-                padded = Image.new(glyph_image.mode,
-                                   (glyph_image.width + 2 * pad,
-                                    glyph_image.height + 2 * pad), bg)
-                padded.paste(glyph_image, (pad, pad))
-                tessapi.SetImage(padded)
+                tessapi.SetImage(pad_image(glyph_image, self.parameter['padding']))
             else:
                 tessapi.SetImage(glyph_image)
             tessapi.SetPageSegMode(PSM.SINGLE_CHAR)
@@ -402,6 +383,7 @@ class TesserocrRecognize(Processor):
                 glyph.add_TextEquiv(TextEquivType(index=choice_no, Unicode=alternative_text, conf=alternative_conf))
     
     def _process_glyphs_in_word(self, result_it, word, word_xywh):
+        LOG = getLogger('processor.TesserocrRecognize')
         if not result_it or result_it.Empty(RIL.SYMBOL):
             LOG.debug("No glyph in word '%s'", word.id)
             return
@@ -590,3 +572,17 @@ def page_update_higher_textequiv_levels(level, pcgts):
                     region_conf /= len(lines)
             region.set_TextEquiv( # replace old, if any
                 [TextEquivType(Unicode=region_unicode, conf=region_conf)])
+
+def pad_image(image, padding):
+    stat = ImageStat.Stat(image)
+    # workaround for Pillow#4925
+    if len(stat.bands) > 1:
+        background = tuple(stat.median)
+    else:
+        background = stat.median[0]
+    padded = Image.new(image.mode,
+                       (image.width + 2 * padding,
+                        image.height + 2 * padding),
+                       background)
+    padded.paste(image, (padding, padding))
+    return padded
